% Filtros para la reconstruccion IAC. Sirve para centrado y ENO.
%     capiacoefiiamc(nl,nr,r)
%     ENTRADAS:
%           nl=numero de nodos a la iquierda de x^{k}_{2i-1} %NO SIRVEN VALORES NEGATIVOS
%           nr=numero de nodos a la derecha de x^{k}_{2i-1} %NO SIRVEN VALORES NEGATIVOS
%           r= grado del polinomio para F, (r-1 para f)
%     SALIDAS:
%           muestra en pantalla los coeficientes que multiplican a f^{k-1} para obtenener f^{k}_{2i-1} mediante IAC
%
% Autor: José Jaime Noguera  +INFO: www.uv.es/anims/noguera

function capiacoefiiamc(nl,nr,r)

r=r-1; %por concordancia con el PDF
A=matriuiamc(nl,nr,r);

C=(A'*A)^(-1)*A';

for i=1:r
   coef0(i)=1-1/(2^i);
   coefl(i)=1/(2^i)-1;
end 

bnlnr0=1+coef0(1:r)*C*ones(nl+nr,1);
bnlnrl=coefl(1:r)*C;

if(nl>=1 && nl>=1)
   solu=[bnlnrl(1:nl),bnlnr0,bnlnrl(nl+1:nl+nr)];
end

if(nl==0 && nr>=1)
   solu=[bnlnr0,bnlnrl(1:nr)];
end

if(nl>=1 && nr==0)
   solu=[bnlnrl(1:nl),bnlnr0];
end

format rational
  solu
format
sprintf('Comienza en f^{k-1}_{i+(%d)} y acaba en f^{k-1}_(i+(%d))',-nl,nr)